.hamburger {
  display: none;
}

body:not(.popup) #header #object-tools {
  display: none;
}

#changelist-search {
  height: 45px /* fallback */;
  height: var(--searchbar-height);
  background: #417690 /* fallback */;
  background: var(--theme-color);
  display: inline;
}

#changelist-search label {
  display: none;
}

#changelist #toolbar form #searchbar,
#changelist-search #searchbar {
  float: left;
  width: 185px;
  height: 35px;
  line-height: 35px;
  margin: 0;
  padding: 5px 5px 5px 15px;
  border: 0;
  border-radius: 0;
  outline-width: 0;
}
#searchbar::-webkit-input-placeholder {
  font-style: italic;
  color: #999;
}

#changelist #toolbar form input[type="submit"],
#changelist-search input[type="submit"] {
  display: inline;
  float: left;
  width: 45px /* fallback */;
  width: var(--searchbar-height);
  height: 45px /* fallback */;
  height: var(--searchbar-height);
  margin: 0;
  padding: 0;
  border-radius: 0;
  border: 0;
  background: #417690 /* fallback */;
  background: var(--theme-color);
  background-image: url(/static/admin/bananas/img/search.svg), linear-gradient(to bottom, rgba(0, 0, 0, 0.15), rgba(0, 0, 0, 0.15));
  background-position: center center;
  background-repeat: no-repeat;
  box-shadow: none;
  text-indent: -20000px;
}

#header #changelist-search input[type="submit"]:hover {
  background-image: url(/static/admin/bananas/img/search.svg), linear-gradient(to bottom, rgba(0, 0, 0, 0.35), rgba(0, 0, 0, 0.35));
}

#changelist-search > div {
  overflow: hidden;
}

#changelist-search .quiet {
  clear: left;
  float: right;
  text-align: right;
  margin: 15px 15px 0 0;
  line-height: 1em;
  text-align: right;
  color: #fff;
}

#changelist-form .results {
  clear: both;
}

@media (max-width: 1024px) {
  .hamburger {
    display: inline;
  }

  body:not(.popup):not(.login) #container {
    padding-left: 0;
  }

  body:not(.login) #header {
    left: auto;
    right: 100%;
    height: 100%;
  }

  body:not(.popup) #title {
    position: absolute;
    left: 0;
  }

  #header,
  #title,
  #messages,
  #content-main,
  #footer {
    transition: transform 200ms /* fallback */;
    transition: var(--sidebar-transition);
  }

  html.is-sidebarOpen #header,
  html.is-sidebarOpen #title,
  html.is-sidebarOpen #messages,
  html.is-sidebarOpen #content-main,
  html.is-sidebarOpen #footer {
    transform: translateX(250px) /* fallback */;
    transform: translateX(var(--sidebar-width));
  }

  body:not(.popup) #content .object-tools {
    display: none;
  }

  body.change-list #header #object-tools,
  body.change-form #header #object-tools {
    display: block;
  }

  .change-list .filtered .results,
  .change-list .filtered .paginator,
  .filtered #toolbar,
  .filtered .actions,
  .filtered div.xfull {
    margin-right: 0;
  }

  #changelist .actions {
    padding: 10px;
    left: 0;
  }

  #changelist .actions label {
    flex: 1 1;
  }

  #changelist .actions select {
    flex: 1 0;
    min-width: auto;
  }

  #changelist .actions .button {
    margin: 0 0 0 10px;
  }

  #changelist .actions span.all,
  #changelist .actions span.action-counter,
  #changelist .actions span.clear,
  #changelist .actions span.question {
    flex: none;
    margin: 0 0 0 10px;
  }
}

@media (max-width: 767px) {
  .login #container {
    box-sizing: border-box;
    min-width: 0;
    width: calc(100% - 30px);
    margin: 30px auto;
  }

  .login .submit-row {
    padding-left: 0;
  }

  .object-tools {
    right: 20px;
  }

  #changelist-search > div {
    max-width: none;
  }

  #header #changelist-filter {
    order: 0;
  }
}

@media (max-width: 438px) {
}
